@@ -20,4 +20,4 @@ def PrintFibonacci(num):
         list.append(c)
         a=b
         b=c
-    print(list)
+    return(list)
